berrycam
========

berrycam makes taking pictures with your Raspberry Pi easy!

Installation
============

Simply run:

::

    $ pip install berrycam

Usage
=====

To use it:

::

    $ berrycam --help
